library flutter_package_demo;

import 'package:flutter/material.dart';

final Color weChatThemeColor = Color.fromRGBO(220, 220, 220, 1);

double screenWidth(BuildContext context) => MediaQuery.of(context).size.width;

double screenHeight(BuildContext context) => MediaQuery.of(context).size.height;

class CCIndexBar extends StatefulWidget {
  final void Function(String str) indexBarCallBack;

  CCIndexBar({this.indexBarCallBack});
  @override
  _CCIndexBarState createState() => _CCIndexBarState();
}

int getIndex(BuildContext context, Offset globalPosition) {
  RenderBox box = context.findRenderObject();
  //坐标系转换,获取y值
  double y = box.globalToLocal(globalPosition).dy;
  //算出字符高度
  var itemHeight = screenHeight(context) / 2.0 / INDEX_WORDS.length;
  //取值范围
  int index = y ~/ itemHeight;
  if (index <= 0) {
    index = 0;
  }
  if (index >= INDEX_WORDS.length) {
    index = INDEX_WORDS.length - 1;
  }
  return index;
}

class _CCIndexBarState extends State<CCIndexBar> {
  Color _bgColor = Color.fromRGBO(1, 1, 1, 0);
  Color _textColor = Colors.grey;
  double _indicatorY = 0.0;
  String _indicatorText = 'A';
  bool _indicatorHidden = true;

  @override
  Widget build(BuildContext context) {
    List<Widget> words = [];
    for (int i = 0; i < INDEX_WORDS.length; i++) {
      words.add(Expanded(
        child: Text(
          INDEX_WORDS[i],
          style: TextStyle(fontSize: 10, color: _textColor),
        ),
      ));
    }

    return Positioned(
      right: 0.0,
      height: screenHeight(context) / 2.0,
      width: 120,
      top: screenHeight(context) / 8.0,
      child: Row(
        children: <Widget>[
          Container(
            alignment: Alignment(0, _indicatorY),
            width: 100,
            child: _indicatorHidden
                ? null
                : Stack(
                    alignment: Alignment(-0.2, 0),
                    children: <Widget>[
                      Image(
                        image: AssetImage('images/qipao.png'),
                        width: 60,
                      ),
                      Text(
                        _indicatorText,
                        style: TextStyle(fontSize: 25, color: Colors.white),
                      ),
                    ],
                  ),
          ),
          GestureDetector(
            onVerticalDragDown: (DragDownDetails details) {
              //基于原点的坐标轴
              print("现在点击的位置是${details.globalPosition}");
              int index = getIndex(context, details.globalPosition);
              widget.indexBarCallBack(INDEX_WORDS[index]);
              setState(() {
                _bgColor = Color.fromRGBO(1, 1, 1, 0.5);
                _textColor = Colors.white;
                _indicatorText = INDEX_WORDS[index];
                _indicatorY = 2.2 / INDEX_WORDS.length * index - 1.1;
                _indicatorHidden = false;
              });
            },
            onVerticalDragUpdate: (DragUpdateDetails deatails) {
              int index = getIndex(context, deatails.globalPosition);
              widget.indexBarCallBack(INDEX_WORDS[index]);
              setState(() {
                _indicatorText = INDEX_WORDS[index];
                _indicatorY = 2.2 / INDEX_WORDS.length * index - 1.1;
                _indicatorHidden = false;
              });
            },
            onVerticalDragEnd: (DragEndDetails details) {
              setState(() {
                _bgColor = Color.fromRGBO(1, 1, 1, 0.0);
                _textColor = Colors.grey;
                _indicatorHidden = true;
              });
            },
            child: Container(
              color: _bgColor,
              child: Column(
                children: words,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

const INDEX_WORDS = [
  '🔍',
  '☆',
  'A',
  'B',
  'C',
  'D',
  'E',
  'F',
  'G',
  'H',
  'I',
  'J',
  'K',
  'L',
  'M',
  'N',
  'O',
  'P',
  'Q',
  'R',
  'S',
  'T',
  'U',
  'V',
  'W',
  'X',
  'Y',
  'Z'
];

/// A Calculator.
class Calculator {
  /// Returns [value] plus 1.
  int addOne(int value) => value + 1;
}
